<?php

/**
 * @file
 *
 * Create administer interface to add fields to contact form
 *
 * @author Bhavin H. Joshi <bhavinjosi@joshics.in>
 */


/**
 *
 * @param $ss__type
 * @return unknown_type
 * @author Bhavin H. Joshi <bhavinjosi@joshics.in>
 */
function contact_field_add_field($op, $ss__type = NULL) {
	if ($op != 'add') {
		$ss__field_type = _get_field_type($op);
		switch($ss__field_type) {
	    case 'textfield':
	      if (module_exists('contact_textfield')) {
	        return drupal_get_form('contact_field_add_field_text_form', $op);
	      }
	      break;
	    case 'textarea':
	      if (module_exists('contact_textfield')) {
	        return drupal_get_form('contact_field_add_field_textarea_form', $op);
	      }
	      break;
	    case 'radios':
	    case 'checkboxes':
	      if (module_exists('contact_option')) {
	        return drupal_get_form('contact_field_add_field_option_form', $op);
	      }
	      break;
	    case 'select':
	      if (module_exists('contact_listfield')) {
	        return drupal_get_form('contact_field_add_field_listfield_form', $op);
	      }
	      break;
	  }
	}
	else{
		switch($ss__type) {
	    case 'text':
	      if (module_exists('contact_textfield')) {
	        return drupal_get_form('contact_field_add_field_text_form', $form_state);
	      }
	      break;
	    case 'area':
	      if (module_exists('contact_textfield')) {
	        return drupal_get_form('contact_field_add_field_textarea_form', $form_state);
	      }
	      break;
	    case 'option':
	      if (module_exists('contact_option')) {
	        return drupal_get_form('contact_field_add_field_option_form', $form_state);
	      }
	      break;
	    case 'list':
	      if (module_exists('contact_listfield')) {
	        return drupal_get_form('contact_field_add_field_listfield_form', $form_state);
	      }
	      break;
	  }
	}
}


/**
 *
 * @return unknown_type
 * @author Bhavin H. Joshi <bhavinjosi@joshics.in>
 */
function contact_field_list_field() {
  $form = array();
  drupal_set_title(t("Manage fields"));
	$am__fields = module_invoke_all('info');
	$form['conatct_field_list'] = array(
    '#type' => 'item',
	  '#value' => _get_fields(),
	  '#description' => t("Only fields from Contact form field module can be edited/deleted here."),
	);
  $links = array();

  if (!empty($am__fields)) {
  	foreach ($am__fields as $key => $value) {
	    $links[] = array(
	      'href' => 'admin/build/contact/add/'. $value['type'],
	      'title' => t("Add a") ." ". $value['title'],
	      'description' => $value['description'],
	    );
	  }
	  $output .= theme('links', $links, '');
  }
  else {
  	drupal_set_message(t("No contact form field module is enabled. Please enable from !module",
  	 array('!module' => l(t("module page"), 'admin/build/modules'))), 'error');
  }

  $form['links'] = array(
    '#type' => 'item',
    '#value' => $output,
    '#weight' => 50,
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#submit' => array('contact_field_list_update'),
    '#value' => t("Save configuration"),
    '#weight' => 49,
  );
  return $form;
}


/**
 *
 * @param $form
 * @param $form_values
 */
function contact_field_list_update($form, $form_values) {
  $am__weight = preg_grep("/^(contact_weight_)/", array_keys($form_values['clicked_button']['#post']));
  if (!empty($am__weight)) {
    for ($i = 0; $i < count($am__weight); $i++) {
      $am__field = preg_split("/^(contact_weight_)/", $am__weight[$i], -1,
        PREG_SPLIT_NO_EMPTY);
      if (!empty($am__field)) {
        db_query("UPDATE {contact_fields} SET weight = %d WHERE field_name = '%s'",
        $form_values['clicked_button']['#post'][$am__weight[$i]], $am__field[0]);
      }
    }
  }
}



/**
 * _get_fields
 *
 * Return themed fields
 *
 * @return unknown_type
 * @author Bhavin H. Joshi <bhavinjosi@joshics.in>
 */
function _get_fields() {
  _set_core_fields();
  $header = array(t("Title"), t("Name"), t("Type"), t("Required"),
    t("Enabled"), t("Weight"), array('data' => t("Operation"), 'colspan' => 2));
  $r__result = db_query("SELECT * FROM {contact_fields} ORDER BY weight ASC");
  $class = "";
  while ($om__result = db_fetch_object($r__result)) {
    if ($om__result->core) {
      $ss__module = '';
      $class = "menu-disabled";
    }
    else {
      $ss__module = '(Module: Contact form field)';
    }
    $am__settings = unserialize($om__result->settings);

    $am__weight['contact_weight_'. $om__result->field_name] = array(
      '#type' => 'textfield',
      '#size' => 5,
      '#default_value' => $om__result->weight,
      '#attributes' => array('class' => 'contact-weight'),
    );

    $row = array(
      $am__settings['title'] ." $ss__module",
      $om__result->field_name,
      $om__result->field_type,
      ($om__result->required ? t("Yes") : t("No")),
      ($om__result->core ? t("Yes") : ($om__result->enabled ? t("Yes") : t("No"))),
      drupal_render(form_builder(NULL, $am__weight, $form_state)),
      ($om__result->core ? NULL : l(t("edit"), 'admin/build/contact/'. $om__result->field_name ."/edit")),
      ($om__result->core ? NULL : l(t("delete"), 'admin/build/contact/'. $om__result->field_name ."/delete")),
    );

    $rows[] = array(
      'id' => 'contact-field',
      'data' => $row,
      'class' => 'draggable '. $class,
    );
    unset($class, $am__weight);
  }

  drupal_add_tabledrag('contact-field', 'order', 'sibling', 'contact-weight');
  return theme('table', $header, $rows, array('id' => 'contact-field'));
}




/**
 * _set_core_fields
 *
 * Set the core fields
 *
 * @author Bhavin H. Joshi <bhavinjosi@joshics.in>
 */
function _set_core_fields() {
  $form_state = array();
  $form_id  = 'contact_site_page';
  module_load_include('inc', 'contact', 'contact.pages');
  $form = contact_mail_page();
  $i = -10;
  $am__exclude = array('#token', 'submit', 'copy', 'contact_information');
  foreach ($form as $name => $attribute) {
    if (!in_array($name, $am__exclude) && !empty($attribute['#type'])) {
     $b__exist = db_result(db_query("SELECT field_name FROM {contact_fields} WHERE core = 1 AND field_name = '%s'", $name));
      if (!$b__exist) {
        $am__settings = array('title' => $attribute['#title']);
        db_query("INSERT INTO {contact_fields} VALUES('%s', '%s', '%s', %d, %d, %d, %d)", $name, $attribute['#type'], serialize($am__settings), $attribute['#required'], 1, $i, 1);
        $i++;
      }
    }
  }
}